<?php

declare(strict_types=1);

namespace Drupal\Tests\external_roles\Unit;

use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\external_roles\Cache\Context\ExternalRolesCacheContext;
use Drupal\external_roles\Service\ExternalRolesInterface;
use Drupal\Tests\UnitTestCase;
use Prophecy\Argument;

/**
 * Tests the external roles cache context.
 *
 * @coversDefaultClass \Drupal\external_roles\Cache\Context\ExternalRolesCacheContext
 * @group external_roles
 */
class ExternalRolesCacheContextTest extends UnitTestCase {

  /**
   * Tests the getContext method.
   *
   * @covers ::getContext
   */
  public function testGetContext(): void {
    $account = $this->prophesize(AccountInterface::class);
    $current_user = $this->prophesize(AccountProxyInterface::class);
    $current_user->getAccount()->willReturn($account->reveal());
    $external_roles = $this->prophesize(ExternalRolesInterface::class);
    $external_roles->getExternalRoles(Argument::any())->willReturn(['foo', 'bar', 'baz']);
    $cache_context = new ExternalRolesCacheContext($current_user->reveal(), $external_roles->reveal());
    $this->assertSame('foo,bar,baz', $cache_context->getContext());
  }

}
